@@ -1,6 +1,7 @@
 package MooX::BuildArgs;
-
-$MooX::BuildArgs::VERSION = '0.05';
+use 5.008001;
+use strictures 2;
+our $VERSION = '0.07';
 
 =head1 NAME
 
@@ -30,7 +31,6 @@ references will not be weakened within L</build_args>.
 =cut
 
 use Moo::Role;
-use strictures 2;
 use namespace::clean;
 
 with 'MooX::BuildArgsHooks';
@@ -91,22 +91,15 @@ L<MooX::SingleArg>
 
 =back
 
-=head1 AUTHOR
+=head1 AUTHORS
 
-Aran Clary Deltac <bluefeet@gmail.com>
-
-=head1 CONTRIBUTORS
-
-=over
-
-=item *
-
-Peter Pentchev <roamE<64>ringlet.net>
-
-=back
+    Aran Clary Deltac <bluefeet@gmail.com>
+    Peter Pentchev <roam@ringlet.net>
 
 =head1 LICENSE
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
+=cut
+
