@@ -1,6 +1,7 @@
 package MooX::SingleArg;
-
-$MooX::SingleArgs::VERSION = '0.05';
+use 5.008001;
+use strictures 2;
+our $VERSION = '0.07';
 
 =head1 NAME
 
@@ -23,7 +24,6 @@ use Class::Method::Modifiers qw( install_modifier );
 use Carp qw( croak );
 
 use Moo::Role;
-use strictures 2;
 use namespace::clean;
 
 with 'MooX::BuildArgsHooks';
@@ -135,22 +135,9 @@ L<MooX::Rebuild>
 
 =back
 
-=head1 AUTHOR
+=head1 AUTHORS AND LICENSE
 
-Aran Clary Deltac <bluefeetE<64>gmail.com>
+See L<MooX::BuildArgs/AUTHORS> and L<MooX::BuildArgs/LICENSE>.
 
-=head1 CONTRIBUTORS
-
-=over
-
-=item *
-
-Peter Pentchev <roamE<64>ringlet.net>
-
-=back
-
-=head1 LICENSE
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+=cut
 
